@@ -36,6 +36,7 @@ EXTENSIONS = {
     'css': {'text', 'css'},
     'csv': {'text', 'csv'},
     'cu': {'text', 'cuda'},
+    'cue': {'text', 'cue'},
     'cuh': {'text', 'cuda'},
     'cxx': {'text', 'c++'},
     'cylc': {'text', 'cylc'},
@@ -50,6 +51,7 @@ EXTENSIONS = {
     'eot': {'binary', 'eot'},
     'eps': {'binary', 'eps'},
     'erb': {'text', 'erb'},
+    'erl': {'text', 'erlang'},
     'exe': {'binary'},
     'eyaml': {'text', 'yaml'},
     'f03': {'text', 'fortran'},
@@ -78,6 +80,7 @@ EXTENSIONS = {
     'hcl': {'text', 'hcl'},
     'hh': {'text', 'header', 'c++'},
     'hpp': {'text', 'header', 'c++'},
+    'hrl': {'text', 'erlang'},
     'hs': {'text', 'haskell'},
     'htm': {'text', 'html'},
     'html': {'text', 'html'},
@@ -106,6 +109,7 @@ EXTENSIONS = {
     'jpg': {'binary', 'image', 'jpeg'},
     'js': {'text', 'javascript'},
     'json': {'text', 'json'},
+    'jsonld': {'text', 'json', 'jsonld'},
     'jsonnet': {'text', 'jsonnet'},
     'json5': {'text', 'json5'},
     'jsx': {'text', 'jsx'},
@@ -123,6 +127,7 @@ EXTENSIONS = {
     'lr': {'text', 'lektor'},
     'lua': {'text', 'lua'},
     'm': {'text', 'objective-c'},
+    'make': {'text', 'makefile'},
     'manifest': {'text', 'manifest'},
     'map': {'text', 'map'},
     'markdown': {'text', 'markdown'},
@@ -163,6 +168,7 @@ EXTENSIONS = {
     'properties': {'text', 'java-properties'},
     'proto': {'text', 'proto'},
     'ps1': {'text', 'powershell'},
+    'pug': {'text', 'pug'},
     'puml': {'text', 'plantuml'},
     'purs': {'text', 'purescript'},
     'pxd': {'text', 'cython'},
@@ -251,6 +257,7 @@ EXTENSIONS = {
     'xsd': {'text', 'xml', 'xsd'},
     'xsl': {'text', 'xml', 'xsl'},
     'yaml': {'text', 'yaml'},
+    'yamlld': {'text', 'yaml', 'yamlld'},
     'yang': {'text', 'yang'},
     'yin': {'text', 'xml', 'yin'},
     'yml': {'text', 'yaml'},
@@ -262,6 +269,7 @@ EXTENSIONS = {
 }
 EXTENSIONS_NEED_BINARY_CHECK = {
     'plist': {'plist'},
+    'ppm': {'image', 'ppm'},
 }
 
 NAMES = {
@@ -330,7 +338,10 @@ NAMES = {
     'pylintrc': EXTENSIONS['ini'] | {'pylintrc'},
     'README': EXTENSIONS['txt'],
     'Rakefile': EXTENSIONS['rb'],
+    'rebar.config': EXTENSIONS['erl'],
     'setup.cfg': EXTENSIONS['ini'],
+    'sys.config': EXTENSIONS['erl'],
+    'sys.config.src': EXTENSIONS['erl'],
     'WORKSPACE': EXTENSIONS['bzl'],
     'wscript': EXTENSIONS['py'],
 }
